/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.osgi.felix.util;

import org.osgi.framework.Bundle;
import org.osgi.framework.BundleContext;
import org.osgi.framework.BundleEvent;

/**
 * @author Shuyang Zhou
 */
public abstract class AbstractExtender
	extends org.apache.felix.utils.extender.AbstractExtender {

	public AbstractExtender() {
		setSynchronous(true);
	}

	@Override
	public void bundleChanged(BundleEvent event) {
		synchronized (this) {
			if (_stopped) {
				return;
			}

			if (event.getType() == BundleEvent.STOPPING) {
				BundleContext bundleContext = getBundleContext();

				Bundle bundle = event.getBundle();

				if (bundleContext == bundle.getBundleContext()) {
					bundleContext.removeBundleListener(this);

					_stopped = true;
				}
			}

			super.bundleChanged(event);
		}
	}

	@Override
	public final void setSynchronous(boolean synchronous) {
		super.setSynchronous(synchronous);
	}

	private boolean _stopped;

}